@@ -88,7 +88,7 @@
 
     (bg-added "#d7e890")
     (bg-added-faint "#e2eba6")
-    (bg-added-refine "#c9da80")
+    (bg-added-refine "#c2d580")
     (fg-added "#2f6500")
 
     (bg-changed "#f5e690")
@@ -126,7 +126,7 @@
     (fg-prompt yellow)
 
     (builtin red)
-    (comment yellow-faint)
+    (comment fg-dim)
     (constant yellow)
     (fnname red-cooler)
     (fnname-call magenta-faint)
@@ -173,9 +173,9 @@
     (mail-cite-2 red-cooler)
     (mail-cite-3 fg-alt)
     (mail-part red-faint)
-    (mail-recipient red-warmer)
-    (mail-subject yellow)
-    (mail-other green-warmer)
+    (mail-recipient yellow)
+    (mail-subject red-warmer)
+    (mail-other green-cooler)
 
     (bg-search-static bg-warning)
     (bg-search-current bg-yellow-intense)
